contents
===========

* monkey_survey.py : tools used to interpret the survey
* score_dream7.m : original matlab file to perform the model1 scoring
* score_dream7_c1s1.m : original matlab file similar to score_dream7 with
  topology challenge.
